==> 4.7.4.tar.gz: terraform-provider-decort/wiki/4.7.1/07.01.24-Resource_decort_image_from_platform_disk.md <==
Функция доступна в провайдере версии 4.6.0 и выше.

_Resource_ функция **decort_image_from_platform_disk** служит для управления образом, созданным из платформенного диска.

## Аргументы

_Resource_ функция **decort_image_from_platform_disk** для создания образа принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| disk_id           | int   | :heavy_check_mark: | ID платформенного диска, из которого будет создан образ |            
| name | string | :heavy_check_mark: | Имя образа<br/>При изменении - изменяет название образа |
| boot_type | string | :heavy_check_mark: | Тип загрузки образа,<br/>возможные варианты: "bios" или "uefi" |
| type | string | :heavy_check_mark: | Тип образа,<br />возможные варианты - "linux", "windows" |
| architecture | string | :heavy_check_mark: | Архитектура образа,<br />возможные варианты - "X86_64" |
| drivers | []string | :heavy_check_mark: | Драйвера,<br/>возможные варианты - ["KVM_X86", "SVA_KVM_X86"] |
| account_id | int | :x: | ID аккаунта владельца образа |
| username | string | :x: | Имя пользователя |
| password | string | :x: | Пароль пользователя |
| sep_id | int | :x: | ID storage endpoint |
| pool_name | string | :x: | Пул для создания образа |
| bootable | bool | :x: | Является ли образ загрузочным. Значение по умолчанию: true. |
| hot_resize | bool | :x: | Использует ли машина горячее изменение размера образа |
| async_mode | bool | :x: | Синхронное создание образа, используется при создании. Значение по умолчанию: false. |

## Возвращаемые значения

В случае успешного выполнения _resource_ функция **decort_image_from_platform_disk** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| account_id | int | accountId привязки образа |
| ckey | string | Ckey |
| acl | string | Информация об аккаунте |
| architecture | string | Архитектура образа, возможен вариант X86_64 |
| boot_type | string | Тип запуска ОС - bios или uefi |
| bootable | bool | Является ли образ загрузочным |
| compute_ci_id | int | ID вычислительного ресурса |
| cd_presented_to | string | Подключение образа |
| deleted_time | int | Время удаления ресурса |
| desc | string | Описание образа |
| drivers | []string | Список используемых драйверов |
| enabled | bool | Доступность образа |
| gid | int | ID платформы, где образ будет создан |
| guid | int | Внутренний id образа, совпадает с image_id |
| history | object{id: int, guid: int, timestamp: int} | История обновлений образа |
| hot_resize | bool | Использует ли машина горячее изменение размера образа |
| type | string | Тип образа: linux, windows или другой |
| last_modified | int | Дата последнего изменения |
| link_to | int | Привязка к образу, используется в виртуальных образах |
| milestones | int | Вехи |
| image_name | string | Название образа |
| network_interface_naming | string | Название сетевого интерфейса |
| pool_name | string | Пул, в котором был создан образ |
| provider_name | string | Наименование провайдера |
| purge_attempts | int | Попытки |
| present_to | []int | Список ID ресурсов для который предоставлен образ |
| res_id | string | ID ресурса |
| rescuecd | bool | cd или нет |
| sep_id | int | storage endpoint provider ID |
| shared_with | []int | Список ресурсов, имеющих доступ к образу |
| size | int | Размер образа |
| status | string | Статус образа |
| tech_status | string | Технический статус |
| unc_path | string | unc path |
| version | string | Версия |

## Пример использования

Пример вызова _resource_ функции **decort_image_from_platform_disk**:

```terraform
resource "decort_image_from_platform_disk" "img" {
  #id диска
  #используется для создания образа
  #обязательный параметр
  #тип - целое число
  disk_id = 1234

  #наименование образа
  #используется для создания и обновления образа
  #обязательный параметр
  #тип - строка
  name = "image_name"

  #тип загрузчика
  #используется для создания образа
  #обязательный параметр
  #возможные значения - bios, uefi
  #тип - строка
  boot_type = "bios"

  #тип образа (linux, windows и др.)
  #используется для создания образа
  #обязательный параметр
  #тип - строка
  type = "linux"

  #архитектура образа
  #используется для создания образа
  #обязательный параметр
  #возможные значения - X86_64
  #тип - строка
  architecture = "X86_64"

  #драйверы компьютов, подходящие для данного образа
  #используется для создания образа
  #обязательный параметр
  #тип - массив строк
  drivers = ["KVM_X86"]

  #имя пользователя для образа
  #используется для создания образа
  #опциональный параметр
  #тип - строка
  #username = "userx"

  #пароль для образа
  #используется для создания образа
  #опциональный параметр
  #тип - строка
  #password = "passx"

  #id аккаунта
  #используется для создания образа
  #опциональный параметр
  #тип - целое число
  #account_id = 138

  #id сепа для образа
  #используется для создания образа
  #опциональный параметр
  #тип - целое число
  #sep_id = 1

  #pool для образа
  #используется для создания образа
  #опциональный параметр
  #тип - строка
  #pool_name = "pool"

  #поддержка hot resize
  #используется для создания образа
  #опциональный параметр
  #тип - булев
  #hot_resize = true

  #флаг загрузочного образа
  #используется для создания образа
  #опциональный параметр
  #по умолчанию - true
  #тип - булев
  #bootable = true

  #флаг для создания образа в асинхронном режиме
  #опциональный параметр
  #по умолчанию - false
  #тип - булев
  #async_mode = true
}
```

После успешного завершения такого вызова **decort_image_from_platform_disk** в переменной `decort_image_from_platform_disk.img` будут сохранены возвращаемые значения.

==> 4.9.0.tar.gz: terraform-provider-decort/wiki/4.9.0/07.01.24-Resource_decort_image_from_platform_disk.md <==
Функция доступна в провайдере версии 4.6.0 и выше.

_Resource_ функция **decort_image_from_platform_disk** служит для управления образом, созданным из платформенного диска.

## Аргументы

_Resource_ функция **decort_image_from_platform_disk** для создания образа принимает следующие аргументы:

| Аргумент | Тип | Обязательный | Описание |
| --- | --- | --- | --- |
| disk_id           | int   | :heavy_check_mark: | ID платформенного диска, из которого будет создан образ |            
| name | string | :heavy_check_mark: | Имя образа<br/>При изменении - изменяет название образа |
| boot_type | string | :heavy_check_mark: | Тип загрузки образа,<br/>возможные варианты: "bios" или "uefi" |
| type | string | :heavy_check_mark: | Тип образа,<br />возможные варианты - "linux", "windows" |
| architecture | string | :heavy_check_mark: | Архитектура образа,<br />возможные варианты - "X86_64" |
| drivers | []string | :heavy_check_mark: | Драйвера,<br/>возможные варианты - ["KVM_X86", "SVA_KVM_X86"] |
| account_id | int | :x: | ID аккаунта владельца образа |
| username | string | :x: | Имя пользователя |
| password | string | :x: | Пароль пользователя |
| pool_name | string | :x: | Пул для создания образа |
| bootable | bool | :x: | Является ли образ загрузочным. Значение по умолчанию: true. |
| hot_resize | bool | :x: | Использует ли машина горячее изменение размера образа |
| async_mode | bool | :x: | Синхронное создание образа, используется при создании. Значение по умолчанию: false. |

## Возвращаемые значения

В случае успешного выполнения _resource_ функция **decort_image_from_platform_disk** возвращает в указанную при вызове переменную следующие значения:

| Параметр | Тип | Описание |
| --- | --- | --- |
| account_id | int | accountId привязки образа |
| ckey | string | Ckey |
| acl | string | Информация об аккаунте |
| architecture | string | Архитектура образа, возможен вариант X86_64 |
| boot_type | string | Тип запуска ОС - bios или uefi |
| bootable | bool | Является ли образ загрузочным |
| compute_ci_id | int | ID вычислительного ресурса |
| cd_presented_to | string | Подключение образа |
| deleted_time | int | Время удаления ресурса |
| desc | string | Описание образа |
| drivers | []string | Список используемых драйверов |
| enabled | bool | Доступность образа |
| gid | int | ID платформы, где образ будет создан |
| guid | int | Внутренний id образа, совпадает с image_id |
| history | object{id: int, guid: int, timestamp: int} | История обновлений образа |
| hot_resize | bool | Использует ли машина горячее изменение размера образа |
| type | string | Тип образа: linux, windows или другой |
| last_modified | int | Дата последнего изменения |
| link_to | int | Привязка к образу, используется в виртуальных образах |
| milestones | int | Вехи |
| image_name | string | Название образа |
| network_interface_naming | string | Название сетевого интерфейса |
| pool_name | string | Пул, в котором был создан образ |
| provider_name | string | Наименование провайдера |
| purge_attempts | int | Попытки |
| present_to | map[string]int | Список ID ресурсов для который предоставлен образ |
| res_id | string | ID ресурса |
| rescuecd | bool | cd или нет |
| sep_id | int | storage endpoint provider ID |
| shared_with | []int | Список ресурсов, имеющих доступ к образу |
| size | int | Размер образа |
| snapshot_id | string | ID снапшота |
| status | string | Статус образа |
| tech_status | string | Технический статус |
| unc_path | string | unc path |
| version | string | Версия |

## Пример использования

Пример вызова _resource_ функции **decort_image_from_platform_disk**:

```terraform
resource "decort_image_from_platform_disk" "img" {
  #id диска
  #обязательный параметр
  #тип - целое число
  #используется при создании
  disk_id = 1234

  #наименование образа
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  name = "image_name"

  #тип загрузчика
  #обязательный параметр
  #возможные значения - bios, uefi
  #тип - строка
  #используется при создании
  boot_type = "bios"

  #тип образа (linux, windows и др.)
  #обязательный параметр
  #тип - строка
  #используется при создании
  type = "linux"

  #архитектура образа
  #обязательный параметр
  #возможные значения - X86_64
  #тип - строка
  #используется при создании
  architecture = "X86_64"

  #драйверы компьютов, подходящие для данного образа
  #обязательный параметр
  #тип - массив строк
  #используется при создании
  drivers = ["KVM_X86"]

  #имя пользователя для образа
  #опциональный параметр
  #тип - строка
  #используется при создании
  #username = "userx"

  #пароль для образа
  #опциональный параметр
  #тип - строка
  #используется при создании
  #password = "passx"

  #id аккаунта
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #account_id = 138

  #pool для образа
  #опциональный параметр
  #тип - строка
  #используется при создании
  #pool_name = "pool"

  #поддержка hot resize
  #опциональный параметр
  #тип - булев
  #используется при создании
  #hot_resize = true

  #флаг загрузочного образа
  #опциональный параметр
  #по умолчанию - true
  #тип - булев
  #используется при создании
  #bootable = true

  #флаг для создания образа в асинхронном режиме
  #опциональный параметр
  #по умолчанию - false
  #тип - булев
  #используется при создании
  #async_mode = true

}
```

После успешного завершения такого вызова **decort_image_from_platform_disk** в переменной `decort_image_from_platform_disk.img` будут сохранены возвращаемые значения.
